@@ -14,8 +14,8 @@
 #endif
 
 #include <QDebug>
+#include <QList>
 #include <QUrl>
-#include <QVector>
 
 KDEConnectDeviceModel::KDEConnectDeviceModel(QObject *parent)
     : QAbstractListModel(parent)
@@ -51,7 +51,7 @@ void KDEConnectDeviceModel::refresh()
         QDBusInterface deviceIface(QStringLiteral("org.kde.kdeconnect"),
                                    QStringLiteral("/modules/kdeconnect/devices/") + deviceId,
                                    QStringLiteral("org.kde.kdeconnect.device"));
-        QDBusReply<bool> pluginReply = deviceIface.call(QStringLiteral("hasPlugin"), QLatin1String("kdeconnect_share"));
+        QDBusReply<bool> pluginReply = deviceIface.call(QStringLiteral("hasPlugin"), QLatin1StringView("kdeconnect_share"));
 
         if (pluginReply.value()) {
             m_devices.push_back({deviceId, deviceIface.property("name").toString()});
